==> percona-server-mongodb-36_3.6.19.orig.tar.gz: percona-server-mongodb-3.6.19-7.0/src/mongo/db/ldap/ldap_manager.cpp <==
/*======
This file is part of Percona Server for MongoDB.

Copyright (C) 2019-present Percona and/or its affiliates. All rights reserved.

    This program is free software: you can redistribute it and/or modify
    it under the terms of the Server Side Public License, version 1,
    as published by MongoDB, Inc.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    Server Side Public License for more details.

    You should have received a copy of the Server Side Public License
    along with this program. If not, see
    <http://www.mongodb.com/licensing/server-side-public-license>.

    As a special exception, the copyright holders give permission to link the
    code of portions of this program with the OpenSSL library under certain
    conditions as described in each individual source file and distribute
    linked combinations including the program with the OpenSSL library. You
    must comply with the Server Side Public License in all respects for
    all of the code used other than as permitted herein. If you modify file(s)
    with this exception, you may extend this exception to your version of the
    file(s), but you are not obligated to do so. If you do not wish to do so,
    delete this exception statement from your version. If you delete this
    exception statement from all source files in the program, then also delete
    it in the license file.
======= */

#define MONGO_LOG_DEFAULT_COMPONENT ::mongo::logger::LogComponent::kAccessControl

#include "mongo/db/ldap/ldap_manager.h"

#include <fmt/format.h>

#include "mongo/base/init.h"
#include "mongo/db/ldap/ldap_manager_impl.h"
#include "mongo/db/ldap_options.h"
#include "mongo/util/assert_util.h"
#include "mongo/util/log.h"

namespace mongo {

std::unique_ptr<LDAPManager> LDAPManager::create() {
    return std::make_unique<LDAPManagerImpl>();
}

namespace {

const auto getLDAPManager =
    ServiceContext::declareDecoration<std::unique_ptr<LDAPManager>>();

}  // namespace

LDAPManager* LDAPManager::get(ServiceContext* service) {
    return getLDAPManager(service).get();
}

LDAPManager* LDAPManager::get(ServiceContext& service) {
    return getLDAPManager(service).get();
}

void LDAPManager::set(ServiceContext* service,
                      std::unique_ptr<LDAPManager> authzManager) {
    getLDAPManager(service) = std::move(authzManager);
}

MONGO_INITIALIZER_WITH_PREREQUISITES(CreateLDAPManager,
                                     ("EndStartupOptionStorage"))
(InitializerContext* context) {
    if (!ldapGlobalParams.ldapServers->empty()) {
        auto ldapManager = LDAPManager::create();
        LDAPManager::set(getGlobalServiceContext(), std::move(ldapManager));
    }
    return Status::OK();
}

}  // namespace mongo

==> percona-server-mongodb-36_3.6.23.orig.tar.gz: percona-server-mongodb-3.6.23-13.0/src/mongo/db/ldap/ldap_manager.cpp <==
/*======
This file is part of Percona Server for MongoDB.

Copyright (C) 2019-present Percona and/or its affiliates. All rights reserved.

    This program is free software: you can redistribute it and/or modify
    it under the terms of the Server Side Public License, version 1,
    as published by MongoDB, Inc.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    Server Side Public License for more details.

    You should have received a copy of the Server Side Public License
    along with this program. If not, see
    <http://www.mongodb.com/licensing/server-side-public-license>.

    As a special exception, the copyright holders give permission to link the
    code of portions of this program with the OpenSSL library under certain
    conditions as described in each individual source file and distribute
    linked combinations including the program with the OpenSSL library. You
    must comply with the Server Side Public License in all respects for
    all of the code used other than as permitted herein. If you modify file(s)
    with this exception, you may extend this exception to your version of the
    file(s), but you are not obligated to do so. If you do not wish to do so,
    delete this exception statement from your version. If you delete this
    exception statement from all source files in the program, then also delete
    it in the license file.
======= */

#define MONGO_LOG_DEFAULT_COMPONENT ::mongo::logger::LogComponent::kAccessControl

#include "mongo/db/ldap/ldap_manager.h"

#include <fmt/format.h>

#include "mongo/base/init.h"
#include "mongo/db/ldap/ldap_manager_impl.h"
#include "mongo/db/ldap_options.h"
#include "mongo/util/assert_util.h"
#include "mongo/util/log.h"

namespace mongo {

std::unique_ptr<LDAPManager> LDAPManager::create() {
    return std::make_unique<LDAPManagerImpl>();
}

namespace {

const auto getLDAPManager =
    ServiceContext::declareDecoration<std::unique_ptr<LDAPManager>>();

}  // namespace

LDAPManager* LDAPManager::get(ServiceContext* service) {
    return getLDAPManager(service).get();
}

LDAPManager* LDAPManager::get(ServiceContext& service) {
    return getLDAPManager(service).get();
}

void LDAPManager::set(ServiceContext* service,
                      std::unique_ptr<LDAPManager> authzManager) {
    getLDAPManager(service) = std::move(authzManager);
}

MONGO_INITIALIZER_WITH_PREREQUISITES(CreateLDAPManager,
                                     ("EndStartupOptionStorage",
                                      "SetGlobalEnvironment"))
(InitializerContext* context) {
    if (!ldapGlobalParams.ldapServers->empty()) {
        auto ldapManager = LDAPManager::create();
        Status status = ldapManager->initialize();
        if (!status.isOK()) {
            error() << "Cannot initialize LDAP server connection (parameters are: "
                    << ldapGlobalParams.logString() << ")";
            return status;
        }
        LDAPManager::set(getGlobalServiceContext(), std::move(ldapManager));
    }
    return Status::OK();
}

}  // namespace mongo
